@@ -81,7 +81,7 @@ class OpenApiSpecDiff(object):
             data, required_params = self._process_nested_obj(body.get("items"), None)
             payload.append(data)
         else:
-            return body.get("example", ""), required_params
+            return body.get("example"), required_params
         return payload, list(set(required_params))
 
     def _process_reqbody(self, reqbody):
@@ -127,8 +127,12 @@ class OpenApiSpecDiff(object):
         #             input_spec = yaml.load(specobj.read())
         # print(input_spec["paths"]["/channels"])
         for api, api_info in input_spec["paths"].items():
+            general_params = input_spec["paths"][api].get("parameters", [])
             for method, method_info in api_info.items():
+                if method in ["parameters"] or str(method).lower() not in ["get", "post", "put", "patch", "delete"]:
+                    continue
                 to_replace = input_spec["paths"][api][method].get("parameters", [])
+                to_replace += general_params
                 # print(api, input_spec["paths"][api][method]["parameters"], "?????", "\n\n")
                 if "requestBody" in method_info:
                     #print(api, method, method_info)
@@ -155,8 +159,13 @@ class OpenApiSpecDiff(object):
                     # print(api, method)
                     # print("found...."+str(to_replace))
                     # raise SystemExit
+                    try:
+                        input_spec["paths"][api][method]["response_payload"] = input_spec["paths"][api][method].get("responses").get("200")["content"]["application/json"]["schema"]["required"]
+                    except:
+                        input_spec["paths"][api][method]["response_payload"] = []
         # print("\n\n\n\nafter\n\n\n")
         # print(input_spec["paths"]["/channels"])
+        #print("\n\n", input_spec,"\n\n")
         return input_spec
 
     @staticmethod
@@ -182,14 +191,19 @@ class OpenApiSpecDiff(object):
             api_endpoint = basepath + apipath
             method_spec_two = list(spec_two["paths"][apipath].keys())
             if apipath not in spec_one.get("paths", {}):
+                general_params = spec_two["paths"][apipath].get("parameters", [])
                 for method in spec_two["paths"][apipath]:
-                    diff["new"].update({apipath: {method: spec_two["paths"][apipath][method].get("parameters", [])}})
+                    if method in ["parameters"] or str(method).lower() not in ["get", "post", "put", "patch", "delete"]:
+                        continue
+                    diff["new"].update({apipath: {method: spec_two["paths"][apipath][method].get("parameters", [])+general_params}})
             else:
                 new_params = []
+                general_params_one = spec_one["paths"][apipath].get("parameters", [])
+                general_params_two = spec_two["paths"][apipath].get("parameters", [])
                 for method in spec_two["paths"][apipath]:
-                    new_params = [_ for _ in spec_two["paths"][apipath][method].get("parameters", []) if
+                    new_params = [_ for _ in spec_two["paths"][apipath][method].get("parameters", [])+general_params_two if
                                   _["name"] not in [x["name"] for x in
-                                                    spec_one["paths"][apipath][method].get("parameters", [])]]
+                                                    spec_one["paths"][apipath][method].get("parameters", [])+general_params_one]]
                     if new_params:
                         diff["changed"].update({apipath: {method: new_params}})
         OpenApiSpecDiff._pretty_print(diff)
